#!/usr/bin/env python

from abc import ABC, abstractmethod

class WoG(ABC):
    def __init__(self, difficulty):
        self.Difficulty = difficulty
        self.play()

    def play(self):
        self.generate()
        self.get_input_from_user()
        return self.compare_results()



#!/usr/bin/env python

from MemoryGame import Game1
from GuessGame import Game2
from CurrencyRouletteGame import Game3
import logging


def MemoryGame(difficulty):     #Starts the game's script at requested difficulty
    print(f'Starting Memory Game with difficulty {difficulty}')
    Game1(difficulty)

def GuessGame(difficulty):      #Starts the game's script at requested difficulty
    print(f'Starting Guess Game with difficulty {difficulty}')
    Game2(difficulty)

def CurrencyRouletteGame(difficulty):       #Starts the game's script at requested difficulty
    print(f'Starting Currency Roulette Game with difficulty {difficulty}')
    Game3(difficulty)

def start_game(game_id, difficulty):        #game_id equals d['game'], vice versa about difficulty, look main() function
    if game_id == 1:
        MemoryGame(difficulty)
    elif game_id == 2:
        GuessGame(difficulty)
    elif game_id == 3:
        CurrencyRouletteGame(difficulty)

def load_game():
    # Has to start with an try exception to get through the ValueError (typing a letter string)
    name = input("Hello There! What is your name? ")
    if name.isdigit() == True:
        logging.error('input is invalid')
        return main()
    print(f"Hello {name} and welcome to the World of Games (WoG). \nHere you can find many cool games to play!")
    # The variable that saves the Game & Difficulty inputs (has to be the first in the block & empty dict)
    d = {}
    # First input the variable as a string, next validate its a digit, next convert it to an integer(!)
    d['Game'] = input("Please choose a game to play: \n 1. Memory Game - a sequence of numbers will appear for 1 second and you have to guess it back. \n 2. Guess Game - guess a number and see if you chose like the computer. \n 3. Currency Roulette - try and guess the value of a random amount of USD to ILS. \n : ")
    while d['Game'].isdigit() == False:
        logging.error('num is invalid')
        return(main())
    d['Game'] = int(d['Game'])
    if d['Game'] not in range(1, 4):
        logging.error('num is invalid')
        return (main())
    d['Difficulty'] = input("Please choose game difficulty from 1 to 5: ")
    while d['Difficulty'].isdigit() == False:
        logging.error('num is invalid')
        return (main())
    d['Difficulty'] = int(d['Difficulty'])
    if d['Difficulty'] not in range(1, 6):
        logging.error('num is invalid')
        return (main())
    return (name, d)

def main():     #The main function which starts the whole process, after it starts load_game for user's inputs, it starts the chosen game at certain difficulty
    FORMAT = '%(message)s'
    logging.basicConfig(format=FORMAT)
    while True:
        exit = input('Are you sure you want to play? (y/n): ')
        if exit.lower() == 'n':
            break
        elif exit.lower() != 'y':
            logging.warning('\ninput is invalid, try again: ')
        else:
            name, d = load_game()
            start_game(d["Game"], d["Difficulty"])

if __name__ == "__main__":
    main()



#!/usr/bin/env python

from MainGame import *
import random
import time

class Game1(WoG):
    def generate(self):
        self.res = random.sample(range(1, 101), self.Difficulty)
        res_str = f"Random number list is {self.res}"
        print(res_str, flush=True, end='\r')
        time.sleep(0.7)
        print('    ' * len(res_str))

    def get_input_from_user(self):
        try:    # must be a try with except because list doesn't support isdigit...
            self.user_res = list(map(int, input('Guess the generated list: ').split()))
        except ValueError:
            print('input is invalid')
            return self.get_input_from_user()


    def compare_results(self):
        i = 1
        while i < 3:  # the user gets 3 tries
            if self.user_res != self.res:
                print('The number you guessed is incorrect')
                i += 1
                self.get_input_from_user()
            else:
                print(f'Congrats, You made it! Generated list was {self.res}!')
                break




#!/usr/bin/env python

from MainGame import *
import random

class Game2(WoG):
    def generate(self):
        self.secret_number = random.randint(1, self.Difficulty)

    def get_input_from_user(self):
        self.User_Guess = input(f'Guess a number between 1 to {self.Difficulty}: ')

    def compare_results(self):
        i = 1
        UserWins = False
        while i < 3:        # the user gets 3 tries
            if self.User_Guess == str(self.secret_number):
                print(f'Congrats, You made it! Secret number was {self.secret_number}!')
                UserWins = True
                break
            else:
                print('The number you guessed is incorrect')
                i += 1
                self.get_input_from_user()
        return UserWins








#!/usr/bin/env python

import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name='WorldOfGamesDEC',
    version='1.3.4',
    author='Mike Joseph',
    author_email='mikeyusufov@gmail.com',
    description='World of Games by Mike Joseph',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/justmike1/WorldOfGames-DEC',
    project_urls = {
        "Bug Tracker": "https://github.com/justmike1/WorldOfGames-DEC/issues"
    },
    license='MIT',
    packages=['WorldOfGamesDEC'],
    install_requires=['requests'],
    scripts=['bin/startWOG.py'],
)




#!/usr/bin/env python

from MainGame import *
import random
import requests
import json

class Game3(WoG):
    def generate(self):
        url = "https://free.currconv.com/api/v7/convert?q=USD_ILS&compact=ultra&apiKey=3eee6e211600d6203628" #  the free API
        res = requests.get(url)
        if res.status_code != 200:
            return -1
        else:
            data = res.text
            parsed = json.loads(data)
            self.USD_ILS = float(parsed["USD_ILS"])     #get the value
            self.random_number = random.randint(1, 101)     #generate random number
            print(f'{self.random_number} USD')
            self.gen_number = round(self.random_number//self.USD_ILS)     # round it to integer
            self.gen_list = list(range(self.gen_number-self.Difficulty, self.gen_number+self.Difficulty)) #generate a list in the range of difficulty
            #print(f'{self.gen_list}') #Delete the sharp symbol when you want to test

    def get_input_from_user(self):
        self.User_Guess = int(input(f'Guess the number in ILS: '))

    def compare_results(self):
        i = 1
        while i < 3:  # the user gets 3 tries
            if self.User_Guess not in self.gen_list:
                print('The number you guessed is incorrect')
                i += 1
                self.get_input_from_user()
            else:
                print(f'Congrats, You made it! Generated number was {self.gen_number}!')
                break




